summaryrefslogtreecommitdiff
path: root/mpf
diff options
context:
space:
mode:
authorTorbjorn Granlund <tege@gmplib.org>2010-04-10 16:24:51 +0200
committerTorbjorn Granlund <tege@gmplib.org>2010-04-10 16:24:51 +0200
commitf11407862a9f554799557c843b385d00df28bcdd (patch)
tree6849ea75be8231725df0898f2f7526badb46d3c3 /mpf
parentb68e24649d8e246fe808af2db99a8064c92f37a7 (diff)
downloadgmp-f11407862a9f554799557c843b385d00df28bcdd.tar.gz
Update comments.
Diffstat (limited to 'mpf')
-rw-r--r--mpf/set_str.c8
1 files changed, 5 insertions, 3 deletions
diff --git a/mpf/set_str.c b/mpf/set_str.c
index 01a175fa6..434937061 100644
--- a/mpf/set_str.c
+++ b/mpf/set_str.c
@@ -24,7 +24,7 @@ along with the GNU MP Library. If not, see http://www.gnu.org/licenses/. */
This still needs work, as suggested by some FIXME comments.
1. Don't depend on superfluous mantissa digits.
2. Allocate temp space more cleverly.
- 3. Use mpn_tdiv_qr instead of mpn_lshift+mpn_divrem.
+ 3. Use mpn_div_q instead of mpn_lshift+mpn_divrem.
*/
#define _GNU_SOURCE /* for DECIMAL_POINT in langinfo.h */
@@ -323,8 +323,10 @@ mpf_set_str (mpf_ptr x, const char *str, int base)
if (divflag)
{
#if 0
- /* FIXME: Should use mpn_tdiv here. */
- mpn_tdiv_qr (qp, mp, 0L, mp, mn, rp, rn);
+ /* FIXME: Should use mpn_div_q here. */
+ ...
+ mpn_div_q (tp, mp, mn, rp, rn, scratch);
+ ...
#else
mp_ptr qp;
mp_limb_t qlimb;